@@ -38,11 +38,11 @@ class DrawItem2(pg.GraphicsObject):
 
     def compute_and_apply_attraction(self, group, movement_speed_fac, anti_gravity_exp, random_movement_fac, weight_exp, attractor_rad_fac, attractor_rads):
 
-            #group.buffer_posx += (group.get_random_neuron_vec() - 0.5)*0.1
-            #group.buffer_posy += (group.get_random_neuron_vec() - 0.5)*0.1
+            #group.buffer_posx += (group.get_neuron_vec('uniform') - 0.5)*0.1
+            #group.buffer_posy += (group.get_neuron_vec('uniform') - 0.5)*0.1
 
-            group.add_x = (group.get_random_neuron_vec() - 0.5) * random_movement_fac# + (-group.buffer_posx)*p2
-            group.add_y = (group.get_random_neuron_vec() - 0.5) * random_movement_fac# + (-group.buffer_posy)*p2#np.sin(group.buffer_posy/lb*2*np.pi)*10*p2
+            group.add_x = (group.get_neuron_vec('uniform') - 0.5) * random_movement_fac# + (-group.buffer_posx)*p2
+            group.add_y = (group.get_neuron_vec('uniform') - 0.5) * random_movement_fac# + (-group.buffer_posy)*p2#np.sin(group.buffer_posy/lb*2*np.pi)*10*p2
 
             for sg in group.afferent_synapses['GLU']:
                 theta_src, rho_src = cart2pol(sg.src.buffer_posx, sg.src.buffer_posy)
@@ -248,13 +248,13 @@ class sun_gravity_plot_tab(TabBase):
             #stringaxis = pg.AxisItem(orientation='left')
             #stringaxis.setTicks([ydict.items()])
 
-            for group in  Network_UI.network.NeuronGroups:
-                group.buffer_posx, group.buffer_posy = pol2cart(group.get_random_neuron_vec() * 2 * np.pi, group.get_random_neuron_vec() * 100)
+            for group in Network_UI.network.NeuronGroups:
+                group.buffer_posx, group.buffer_posy = pol2cart(group.get_neuron_vec('uniform') * 2 * np.pi, group.get_neuron_vec('uniform') * 100)
 
             def c(event):
                 for group in event.currentItem.groups:
                     dx = group.buffer_posx-event.pos().x()
-                    dy = group.buffer_posy-event.pos().y()*-1
+                    dy = group.buffer_posy-event.pos().y() * -1
                     d = np.sqrt(dx*dx+dy*dy)
 
                     indices = np.where(d<1)[0]
@@ -277,15 +277,15 @@ class sun_gravity_plot_tab(TabBase):
 
             if Network_UI.network['grammar_act', 0] is not None: 
                 source = Network_UI.network['grammar_act'][0]
-                self.base_char_masks_dict=dict([(char, source.get_activation(i, Network_UI.network['prediction_source', 0])) for i, char in enumerate(source.alphabet)])
+                self.base_char_masks_dict = dict([(char, source.get_activation(i, Network_UI.network['prediction_source', 0])) for i, char in enumerate(source.alphabet)])
 
             elif Network_UI.network['drum_act', 0] is not None: 
                 source = Network_UI.network['drum_act'][0]
-                self.base_char_masks_dict=dict([(source.instruments[char], source.get_activation(i, Network_UI.network['prediction_source', 0])) for i, char in enumerate(source.alphabet)])
+                self.base_char_masks_dict = dict([(source.instruments[char], source.get_activation(i, Network_UI.network['prediction_source', 0])) for i, char in enumerate(source.alphabet)])
             
             elif Network_UI.network['music_act', 0] is not None: 
                 source = Network_UI.network['music_act'][0]
-                self.base_char_masks_dict=dict([(source.midi_index_to_notestring(char), source.get_activation(i, Network_UI.network['prediction_source', 0])) for i, char in enumerate(source.alphabet)])
+                self.base_char_masks_dict = dict([(source.midi_index_to_notestring(char), source.get_activation(i, Network_UI.network['prediction_source', 0])) for i, char in enumerate(source.alphabet)])
             
 
             Network_UI.Next_H_Block()
