@@ -10,6 +10,10 @@ import imageio
 #import matplotlib.pylab as plt
 #storage_manager_folder = '../../Data/StorageManager/'
 
+def create_folder_if_not_exist(path):
+    if not os.path.exists(path):
+        os.mkdir(path)
+
 def get_data_folder(create_when_not_found=True):
     path='./'
     while os.path.isdir(path):
@@ -26,7 +30,7 @@ def get_data_folder(create_when_not_found=True):
     #raise Exception('No "Data" folder found above current working directory! Please create dirctory: ".../Project/Data".')
 
 def zipDir(dirPath, zipPath, filter):
-    zipf = zipfile.ZipFile(zipPath , mode='w')
+    zipf = zipfile.ZipFile(zipPath, mode='w')
     lenDirPath = len(dirPath)
     for root, _, files in os.walk(dirPath):
         for file in files:
@@ -40,6 +44,7 @@ def zipDir(dirPath, zipPath, filter):
                 zipf.write(filePath , filePath[lenDirPath :] )
     zipf.close()
 
+
 class StorageManager:
 
     def dict_to_folder_name(self, dict):
@@ -50,12 +55,12 @@ class StorageManager:
             result += str(k).replace(' ', '')+'='+str(v).replace(' ', '')
         return result
 
-    def __init__(self, main_folder_name, folder_name=None, random_nr=False, print_msg=True, add_new_when_exists=True):
+    def __init__(self, main_folder_name, folder_name=None, random_nr=False, print_msg=True, add_new_when_exists=True, data_folder=get_data_folder()):
 
         if type(main_folder_name) is dict:
             main_folder_name = self.dict_to_folder_name(main_folder_name)
 
-        storage_manager_folder = get_data_folder()+'/StorageManager/'
+        storage_manager_folder = data_folder +'/StorageManager/'
 
         if not os.path.exists(storage_manager_folder):
             try:
@@ -98,8 +103,7 @@ class StorageManager:
             new = True
 
         self.config_file_name = 'config.ini'
-        self.config = ConfigParser()
-        self.config.read(self.absolute_path+self.config_file_name)
+        self.config=None
 
         self.frame_counter = {}
 
@@ -108,6 +112,11 @@ class StorageManager:
                 print(self.absolute_path)
             self.save_param('time', time.time())
 
+    def init_config(self):
+        if self.config is None:
+            self.config = ConfigParser()
+            self.config.read(self.absolute_path + self.config_file_name)
+
     def save_recorder(self, tag, recorder, keys=[]):
         if type(keys) is str:
             keys=[keys]
@@ -134,6 +143,7 @@ class StorageManager:
             self.save_param(key, d[key], section)
 
     def save_param(self, key, value, section='Parameters'):
+        self.init_config()
         if not self.config.has_section(section):
             self.config.add_section(section)
         self.config.set(section, key, str(value))
@@ -175,11 +185,14 @@ class StorageManager:
         if reset_frame_counter:
             self.frame_counter[key] = 0
 
-    def load_param(self, key, section='Parameters', default=None):#casting!!!
+    def load_param(self, key, section='Parameters', default=None, return_string=False):#casting!!!
+        self.init_config()
         try:
             s = self.config.get(section, key)
         except:
             return default
+        if return_string:
+            return s
         if len(s) > 0:
             if s=='True':
                 return True
@@ -208,12 +221,22 @@ class StorageManager:
                     zf.write(os.path.join(dirname, filename))
         zf.close()
 
+class SimpleStorageManager(StorageManager):
+
+    def __init__(self, folder):
+        self.absolute_path = folder
+
+        self.config_file_name = 'config.ini'
+        self.config = None
+
+        self.frame_counter = {}
+
 
 class StorageManagerGroup:
 
-    def __init__(self, Tag, main_folder_name=None):
+    def __init__(self, Tag, main_folder_name=None, data_folder=get_data_folder()):
 
-        storage_manager_folder = get_data_folder() + '/StorageManager/'
+        storage_manager_folder = data_folder + '/StorageManager/'
 
         if main_folder_name is None:
             main_folder_name = Tag
@@ -226,14 +249,14 @@ class StorageManagerGroup:
         ct = 0
         for folder in os.listdir(self.absolute_path):
             if os.path.isdir(self.absolute_path+folder) and Tag in folder:
-                self.StorageManagerList.append(StorageManager(Tag, folder, add_new_when_exists=False))
+                self.StorageManagerList.append(StorageManager(Tag, folder, add_new_when_exists=False, data_folder=data_folder))
 
-                app = folder.split('_')[1:]
-                if len(app) > 1:
-                    self.StorageManagerList[-1].save_param('appendix', app[1])
+                #app = folder.split('_')[1:]
+                #if len(app) > 1:
+                #    self.StorageManagerList[-1].save_param('appendix', app[1])
 
-                self.StorageManagerList[-1].save_param('folder_number', ct)
-                ct += 1
+                #self.StorageManagerList[-1].save_param('folder_number', ct)
+                #ct += 1
 
     def sort_by(self, param, section='Parameters'):
         self.StorageManagerList = sorted(self.StorageManagerList, key=lambda sm: sm.load_param(param, section, default=-np.inf))
@@ -258,7 +281,7 @@ class StorageManagerGroup:
         results = []
         for param in params:
             results.append(np.array(self.get_param_list(param, section)))
-            remove*=results[-1]!=None
+            remove*=(results[-1]!=None)*(results[-1]!=np.nan)
         results = np.array(results)
         if remove_None:
             results=results[:,remove]#np.where(results is not None)#.any(axis=1)
@@ -278,7 +301,7 @@ class StorageManagerGroup:
         key_q = parts[0]
 
         for sm in self.StorageManagerList:
-            param = sm.load_param(key_q)
+            param = sm.load_param(key_q, return_string=True)
             if param is not None:
                 new_q = query.replace(key_q, param)
                 if eval(new_q):
