@@ -1,7 +1,14 @@
-from PymoNNto.NetworkCore.Neuron_Group import *
+from PymoNNto.NetworkCore.Behaviour import *
 import math
 import numpy as np
 
+#np.tile(src.x, (1, dst.size)).reshape(dst.size, src.size)
+def vec_to_mat(vec, repeat_count):
+    return np.tile(vec, (1, repeat_count)).reshape(repeat_count, vec.shape[0])
+
+#np.tile(dst.x, (1, src.size)).reshape(src.size, dst.size).transpose()
+def vec_to_mat_transposed(vec, repeat_count):
+    return vec_to_mat(vec, repeat_count).transpose()
 
 def rotation_matrix(axis, theta):
     """
@@ -28,13 +35,13 @@ def get_squared_dim(number_of_neurons, depth=1, round_up=True):
     w=divider
     h=int(number_of_neurons/divider)
 
-    print(w,h)
+    print('set network size to', w, 'x', h)
     return NeuronDimension(width=w, height=h, depth=depth)
 
 
 class NeuronDimension(Behaviour):
 
-    run_on_init = True
+    set_variables_on_init = True
 
     #def __init__(self, width=1, height=1, depth=1):
     #    super().__init__()
@@ -112,13 +119,11 @@ class NeuronDimension(Behaviour):
 
 
     def set_variables(self, neurons):
-        self.add_tag('structure')
-
         self.width = self.get_init_attr('width', 1, neurons)
         self.height = self.get_init_attr('height', 1, neurons)
         self.depth = self.get_init_attr('depth', 1, neurons)
 
-        for pg in self.get_init_attr('input_pattern_groups', [], neurons):
+        for pg in self.get_init_attr('input_patterns', [], neurons):
             dim = pg.get_pattern_dimension()#.reconstruct_pattern(None)
             if len(dim) > 0: self.height = np.maximum(self.height, dim[0])
             if len(dim) > 1: self.width = np.maximum(self.width, dim[1])
@@ -142,5 +147,3 @@ class NeuronDimension(Behaviour):
 
 
 
-
-
