@@ -1,21 +1,39 @@
-import numpy as np
 from PymoNNto.NetworkCore.Base import *
-from numpy.random import *
+from PymoNNto.Exploration.Evolution.Interface_Functions import *
 
 class Behaviour(NetworkObjectBase):
     #modificaton_reset_vars = []
-    run_on_init = False
+    set_variables_on_init = False
 
     def __init__(self, **kwargs):
         self.init_kwargs = kwargs
         self.used_attr_keys = []
         self.behaviour_enabled = self.get_init_attr('behaviour_enabled', True, None)
         super().__init__(tag=self.get_init_attr('tag', None, None))
+        self.add_tag(self.__class__.__name__)
 
     def run_on_neuron_init(self):
         self.run_on_neuron_init_var = True
         return self
 
+    def set_gene_variables(self):
+        current_genome = {}
+        for variable_key in self.init_kwargs:
+            while type(self.init_kwargs[variable_key]) is str and '[' in self.init_kwargs[variable_key] and ']' in \
+                    self.init_kwargs[variable_key]:
+                s = self.init_kwargs[variable_key]
+
+                start = s.index('[')
+                end = s.index(']')
+                internal = s[start + 1: end].split('#')
+                default_value = float(internal[0])
+                gene_key = internal[1]
+
+                current_genome[gene_key] = get_gene(gene_key, default_value)
+
+                self.init_kwargs[variable_key] = s[:start] + '{:.15f}'.format(current_genome[gene_key]).rstrip('0').rstrip('.') + s[end + 1:]
+        return current_genome
+
     def diversity_string_to_vec2(self, ds, neurons):
 
         if 'same(' in ds and ds[-1] == ')':
@@ -159,7 +177,11 @@ class Behaviour(NetworkObjectBase):
             if not key in self.used_attr_keys:
                 print('Warning: "'+key+'" not used in set_variables of '+str(self)+' behaviour! Make sure that "'+key+'" is spelled correctly and get_init_attr('+key+',...) is called in set_variables. Valid attributes are:'+str(self.used_attr_keys))
 
-    def get_init_attr(self, key, default, neurons=None, do_not_diversify=False, search_other_behaviours=False):
+    def get_init_attr(self, key, default, neurons=None, do_not_diversify=False, search_other_behaviours=False, required=False):
+
+        if required and not key in self.init_kwargs:
+            print('Warning:',key,'has to be specified for the behaviour to run properly.', self)
+
         self.used_attr_keys.append(key)
 
         result = self.init_kwargs.get(key, default)
@@ -187,11 +209,20 @@ class Behaviour(NetworkObjectBase):
     #    return None
 
 
+    def visualize_module(self, vmi=None, vmo=None, vma=None):
+        from PymoNNto.Exploration.Visualization import Module_visualizer as drawer
+        self.visualization_module_inputs = vmi
+        self.visualization_module_outputs = vmo
+        self.visualization_module_attributes = vma
+        md = drawer.module_drawer()
+        md.add_module(self)
+        md.show()
 
-    def initialize_synapse_attr(self, target_attr, density, equal_range, random_range, neurons, synapse_type, all_neurons_same=False):
-        for s in neurons.afferent_synapses[synapse_type]:
-            s.enabled *= s.get_random_synapse_mat(density, all_neurons_same) > 0.0
-            setattr(s, target_attr, s.enabled*(s.get_synapse_mat()+equal_range+s.get_random_synapse_mat(1.0, all_neurons_same)*random_range))#s.shape_mat*#neurons.GABA_strength+neurons.min_GABA_strength
+
+    #def initialize_synapse_attr(self, target_attr, density, equal_range, random_range, neurons, synapse_type, all_neurons_same=False):
+    #    for s in neurons.afferent_synapses[synapse_type]:
+    #        s.enabled *= s.get_synapse_mat('uniform',density=density, clone_along_first_axis=all_neurons_same) > 0.0
+    #        setattr(s, target_attr, s.enabled*(s.get_synapse_mat()+equal_range+s.get_synapse_mat('uniform',density=1.0, clone_along_first_axis=all_neurons_same)*random_range))#s.shape_mat*#neurons.GABA_strength+neurons.min_GABA_strength
 
 
 
