@@ -4,8 +4,8 @@ import random
 #from NetworkBehaviour.Input.Activator import *
 from PymoNNto.NetworkCore.Base import *
 from PymoNNto.NetworkCore.Synapse_Group import *
-from PymoNNto.Exploration.Evolution.Interface_Functions import *
 import copy
+import time
 
 class Network(NetworkObjectBase):
 
@@ -19,6 +19,10 @@ class Network(NetworkObjectBase):
 
         self.iteration = 0
 
+        for k in self.behaviour:
+            if self.behaviour[k].set_variables_on_init:
+                self.behaviour[k].set_variables(self)
+
 
     def set_mechanisms(self, keys, enabeled):
         for key in keys:
@@ -50,24 +54,13 @@ class Network(NetworkObjectBase):
                 if (keys is None or key in keys) and hasattr(obj.behaviour[key], 'clear_recorder'):
                     obj.behaviour[key].clear_recorder()
 
-    def set_marked_variables(self, info=True, storage_manager=None):
-        current_genome={}
+    def set_gene_variables(self, info=True, storage_manager=None):
+        current_genome = {}
+
         for obj in self.all_behaviour_objects():
             for key in obj.behaviour:
-                b=obj.behaviour[key]
-                for variable_key in b.init_kwargs:
-                    while type(b.init_kwargs[variable_key]) is str and '[' in b.init_kwargs[variable_key] and ']' in b.init_kwargs[variable_key]:
-                        s = b.init_kwargs[variable_key]
-
-                        start = s.index('[')
-                        end = s.index(']')
-                        internal = s[start+1: end].split('#')
-                        default_value = float(internal[0])
-                        gene_key = internal[1]
-
-                        current_genome[gene_key] = get_gene(gene_key, default_value)
-
-                        b.init_kwargs[variable_key] = s[:start]+'{:.15f}'.format(current_genome[gene_key]).rstrip('0').rstrip('.')+s[end+1:]
+                b = obj.behaviour[key]
+                current_genome.update(b.set_gene_variables())
         if info:
             print('default genome:', current_genome)
 
@@ -98,16 +91,19 @@ class Network(NetworkObjectBase):
 
         print('initialize tren... Neurons: ', neuron_count, '|', len(self.NeuronGroups), ' blocks, Synapses: ', sysnape_count, '|', len(self.SynapseGroups),' blocks')
 
-    def initialize(self, evo_replace_param_list=None, info=False, warnings=True, storage_manager=None):
+    def save_descriptions(self, storage_manager=None):
+        if storage_manager is not None:
+            return #todo: implement
+            #storage_manager.save_param(key, value, section='Parameters')
 
-        self.set_marked_variables(info=info, storage_manager=storage_manager)
+
+    def initialize(self, info=False, warnings=True, storage_manager=None):
+
+        self.set_gene_variables(info=info, storage_manager=storage_manager)
 
         if info:
             self.print_net_info()
 
-        if evo_replace_param_list is not None:
-            self.set_marked_variables(evo_replace_param_list)
-
         #self.old_param_list = self.get_all_params()
 
         self.set_synapses_to_neuron_groups()
@@ -127,6 +123,8 @@ class Network(NetworkObjectBase):
 
         self.check_unique_tags(warnings)
 
+        self.save_descriptions(storage_manager)
+
     def check_unique_tags(self,warnings=True):
         unique_tags=[]
         for ng in self.NeuronGroups:
@@ -218,10 +216,11 @@ class Network(NetworkObjectBase):
             for obj in self.all_behaviour_objects():
 
                 if timestep in obj.behaviour:
-                    if not obj.behaviour[timestep].run_on_init:
+                    if not obj.behaviour[timestep].set_variables_on_init:
                         obj.behaviour[timestep].set_variables(obj)
                         obj.behaviour[timestep].check_unused_attrs()
 
+
             '''
             for ng in self.NeuronGroups:
                 if timestep in ng.behaviour:
@@ -332,11 +331,11 @@ class Network(NetworkObjectBase):
 
         for t in range(int(outside_it)):
             if measure_block_time:
-                start_time = time()
+                start_time = time.time()
             for i in range(int(block_iterations)):
                 self.simulate_iteration()
             if measure_block_time:
-                time_diff = (time() - start_time) * 1000
+                time_diff = (time.time() - start_time) * 1000
 
                 print('\r{}xBatch: {}/{} ({}%) {:.3f}ms'.format(block_iterations,t+1, outside_it, int(100/outside_it*(t+1)),time_diff), end='')#, end='')
 
@@ -357,6 +356,7 @@ class Network(NetworkObjectBase):
     #    for sg in SynapseGroups:
     #        self.partition_Synapse_Group(sg)
 
+    '''
     def partition_Synapse_Group3(self, synapse_group, steps):
         return self.partition_Synapse_Group2(synapse_group, synapse_group.dst.partition_steps(steps))
 
@@ -402,8 +402,9 @@ class Network(NetworkObjectBase):
         self.SynapseGroups.remove(synapse_group)
 
         return syn_sub_groups
+    '''
 
-
+    '''
     def partition_Synapse_Group(self, syn_group, receptive_field_size=1, split_size=1):
 
         src = syn_group.src
@@ -509,6 +510,7 @@ class Network(NetworkObjectBase):
         self.SynapseGroups.remove(syn_group)
 
         return sub_groups
+    '''
 
 
 
