@@ -1,7 +1,10 @@
 from PymoNNto.NetworkCore.Network import *
+from PymoNNto.NetworkCore.Behaviour import *
 from PymoNNto.NetworkCore.Neuron_Group import *
 from PymoNNto.NetworkCore.Synapse_Group import *
 from PymoNNto.NetworkBehaviour.Structure.Structure import *
+from PymoNNto.NetworkBehaviour.Structure.Partition import *
+from PymoNNto.NetworkBehaviour.Structure.Receptive_Fields import *
 from PymoNNto.NetworkBehaviour.Recorder.Recorder import *
 
 #from PymoNNto.NetworkBehaviour.Structure.Structure import get_squared_dim
